==> kubernetes-model-networking-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressSpecFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressSpecFluent<A extends IngressSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildDefaultBackend instead.
   * @return The buildable object.
   */
  @Deprecated
  public IngressBackend getDefaultBackend();
  public IngressBackend buildDefaultBackend();
  public A withDefaultBackend(IngressBackend defaultBackend);
  public Boolean hasDefaultBackend();
  public IngressSpecFluent.DefaultBackendNested<A> withNewDefaultBackend();
  public IngressSpecFluent.DefaultBackendNested<A> withNewDefaultBackendLike(IngressBackend item);
  public IngressSpecFluent.DefaultBackendNested<A> editDefaultBackend();
  public IngressSpecFluent.DefaultBackendNested<A> editOrNewDefaultBackend();
  public IngressSpecFluent.DefaultBackendNested<A> editOrNewDefaultBackendLike(IngressBackend item);
  public String getIngressClassName();
  public A withIngressClassName(String ingressClassName);
  public Boolean hasIngressClassName();
  public A addToRules(Integer index,IngressRule item);
  public A setToRules(Integer index,IngressRule item);
  public A addToRules(io.fabric8.kubernetes.api.model.networking.v1.IngressRule... items);
  public A addAllToRules(Collection<IngressRule> items);
  public A removeFromRules(io.fabric8.kubernetes.api.model.networking.v1.IngressRule... items);
  public A removeAllFromRules(Collection<IngressRule> items);
  public A removeMatchingFromRules(Predicate<IngressRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IngressRule> getRules();
  public List<IngressRule> buildRules();
  public IngressRule buildRule(Integer index);
  public IngressRule buildFirstRule();
  public IngressRule buildLastRule();
  public IngressRule buildMatchingRule(Predicate<IngressRuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<IngressRuleBuilder> predicate);
  public A withRules(List<IngressRule> rules);
  public A withRules(io.fabric8.kubernetes.api.model.networking.v1.IngressRule... rules);
  public Boolean hasRules();
  public IngressSpecFluent.RulesNested<A> addNewRule();
  public IngressSpecFluent.RulesNested<A> addNewRuleLike(IngressRule item);
  public IngressSpecFluent.RulesNested<A> setNewRuleLike(Integer index,IngressRule item);
  public IngressSpecFluent.RulesNested<A> editRule(Integer index);
  public IngressSpecFluent.RulesNested<A> editFirstRule();
  public IngressSpecFluent.RulesNested<A> editLastRule();
  public IngressSpecFluent.RulesNested<A> editMatchingRule(Predicate<IngressRuleBuilder> predicate);
  public A addToTls(Integer index,IngressTLS item);
  public A setToTls(Integer index,IngressTLS item);
  public A addToTls(io.fabric8.kubernetes.api.model.networking.v1.IngressTLS... items);
  public A addAllToTls(Collection<IngressTLS> items);
  public A removeFromTls(io.fabric8.kubernetes.api.model.networking.v1.IngressTLS... items);
  public A removeAllFromTls(Collection<IngressTLS> items);
  public A removeMatchingFromTls(Predicate<IngressTLSBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTls instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IngressTLS> getTls();
  public List<IngressTLS> buildTls();
  public IngressTLS buildTl(Integer index);
  public IngressTLS buildFirstTl();
  public IngressTLS buildLastTl();
  public IngressTLS buildMatchingTl(Predicate<IngressTLSBuilder> predicate);
  public Boolean hasMatchingTl(Predicate<IngressTLSBuilder> predicate);
  public A withTls(List<IngressTLS> tls);
  public A withTls(io.fabric8.kubernetes.api.model.networking.v1.IngressTLS... tls);
  public Boolean hasTls();
  public IngressSpecFluent.TlsNested<A> addNewTl();
  public IngressSpecFluent.TlsNested<A> addNewTlLike(IngressTLS item);
  public IngressSpecFluent.TlsNested<A> setNewTlLike(Integer index,IngressTLS item);
  public IngressSpecFluent.TlsNested<A> editTl(Integer index);
  public IngressSpecFluent.TlsNested<A> editFirstTl();
  public IngressSpecFluent.TlsNested<A> editLastTl();
  public IngressSpecFluent.TlsNested<A> editMatchingTl(Predicate<IngressTLSBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface DefaultBackendNested<N> extends Nested<N>,IngressBackendFluent<IngressSpecFluent.DefaultBackendNested<N>>{
    public N and();
    public N endDefaultBackend();
    
  }
  public interface RulesNested<N> extends Nested<N>,IngressRuleFluent<IngressSpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  public interface TlsNested<N> extends Nested<N>,IngressTLSFluent<IngressSpecFluent.TlsNested<N>>{
    public N and();
    public N endTl();
    
  }
  
}

==> kubernetes-model-networking-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressSpecFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface IngressSpecFluent<A extends IngressSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildDefaultBackend instead.
   * @return The buildable object.
   */
  @Deprecated
  public IngressBackend getDefaultBackend();
  public IngressBackend buildDefaultBackend();
  public A withDefaultBackend(IngressBackend defaultBackend);
  public Boolean hasDefaultBackend();
  public IngressSpecFluent.DefaultBackendNested<A> withNewDefaultBackend();
  public IngressSpecFluent.DefaultBackendNested<A> withNewDefaultBackendLike(IngressBackend item);
  public IngressSpecFluent.DefaultBackendNested<A> editDefaultBackend();
  public IngressSpecFluent.DefaultBackendNested<A> editOrNewDefaultBackend();
  public IngressSpecFluent.DefaultBackendNested<A> editOrNewDefaultBackendLike(IngressBackend item);
  public String getIngressClassName();
  public A withIngressClassName(String ingressClassName);
  public Boolean hasIngressClassName();
  public A addToRules(int index,IngressRule item);
  public A setToRules(int index,IngressRule item);
  public A addToRules(io.fabric8.kubernetes.api.model.networking.v1.IngressRule... items);
  public A addAllToRules(Collection<IngressRule> items);
  public A removeFromRules(io.fabric8.kubernetes.api.model.networking.v1.IngressRule... items);
  public A removeAllFromRules(Collection<IngressRule> items);
  public A removeMatchingFromRules(Predicate<IngressRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildRules instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IngressRule> getRules();
  public List<IngressRule> buildRules();
  public IngressRule buildRule(int index);
  public IngressRule buildFirstRule();
  public IngressRule buildLastRule();
  public IngressRule buildMatchingRule(Predicate<IngressRuleBuilder> predicate);
  public Boolean hasMatchingRule(Predicate<IngressRuleBuilder> predicate);
  public A withRules(List<IngressRule> rules);
  public A withRules(io.fabric8.kubernetes.api.model.networking.v1.IngressRule... rules);
  public Boolean hasRules();
  public IngressSpecFluent.RulesNested<A> addNewRule();
  public IngressSpecFluent.RulesNested<A> addNewRuleLike(IngressRule item);
  public IngressSpecFluent.RulesNested<A> setNewRuleLike(int index,IngressRule item);
  public IngressSpecFluent.RulesNested<A> editRule(int index);
  public IngressSpecFluent.RulesNested<A> editFirstRule();
  public IngressSpecFluent.RulesNested<A> editLastRule();
  public IngressSpecFluent.RulesNested<A> editMatchingRule(Predicate<IngressRuleBuilder> predicate);
  public A addToTls(int index,IngressTLS item);
  public A setToTls(int index,IngressTLS item);
  public A addToTls(io.fabric8.kubernetes.api.model.networking.v1.IngressTLS... items);
  public A addAllToTls(Collection<IngressTLS> items);
  public A removeFromTls(io.fabric8.kubernetes.api.model.networking.v1.IngressTLS... items);
  public A removeAllFromTls(Collection<IngressTLS> items);
  public A removeMatchingFromTls(Predicate<IngressTLSBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTls instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IngressTLS> getTls();
  public List<IngressTLS> buildTls();
  public IngressTLS buildTl(int index);
  public IngressTLS buildFirstTl();
  public IngressTLS buildLastTl();
  public IngressTLS buildMatchingTl(Predicate<IngressTLSBuilder> predicate);
  public Boolean hasMatchingTl(Predicate<IngressTLSBuilder> predicate);
  public A withTls(List<IngressTLS> tls);
  public A withTls(io.fabric8.kubernetes.api.model.networking.v1.IngressTLS... tls);
  public Boolean hasTls();
  public IngressSpecFluent.TlsNested<A> addNewTl();
  public IngressSpecFluent.TlsNested<A> addNewTlLike(IngressTLS item);
  public IngressSpecFluent.TlsNested<A> setNewTlLike(int index,IngressTLS item);
  public IngressSpecFluent.TlsNested<A> editTl(int index);
  public IngressSpecFluent.TlsNested<A> editFirstTl();
  public IngressSpecFluent.TlsNested<A> editLastTl();
  public IngressSpecFluent.TlsNested<A> editMatchingTl(Predicate<IngressTLSBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface DefaultBackendNested<N> extends Nested<N>,IngressBackendFluent<IngressSpecFluent.DefaultBackendNested<N>>{
    public N and();
    public N endDefaultBackend();
    
  }
  public interface RulesNested<N> extends Nested<N>,IngressRuleFluent<IngressSpecFluent.RulesNested<N>>{
    public N and();
    public N endRule();
    
  }
  public interface TlsNested<N> extends Nested<N>,IngressTLSFluent<IngressSpecFluent.TlsNested<N>>{
    public N and();
    public N endTl();
    
  }
  
}
